@@ -1,14 +1,11 @@
-Err_exp_item<-function(X){
-  J<-colnames(X)
-  EO<- Err_exp(X);dimnames(EO) <- list(J,J,J)
-  f<-colnames(X)
-  nn<-length(f)
-  cmbf<-combinations(n=nn, r=3, v=f, set=FALSE, repeats.allowed=FALSE)
+Err_exp_item <- function(X,K=K,n=n,J=J,EO=EO){
+  nn<-length(J)
+  cmbf<-combinations(n=nn, r=3, v=J, set=FALSE, repeats.allowed=FALSE)
   ncm<-nrow(cmbf)
   expe<-vector()
   for (i in 1 : nn){
     ind <- NULL;vind <- NULL
-    ind <- f[i]
+    ind <- J[i]
     for (g in 1:ncm){
       if (ind %in% cmbf[g,]){
         vind <- c(vind,g)
@@ -20,4 +17,4 @@ Err_exp_item<-function(X){
     expe <- c(expe,EOind)
   }
   return(expe)
-}
+}
\ No newline at end of file
