@@ -1,14 +1,11 @@
-Err_obs_item <-function(X){
-  J <- colnames(X)
-  O <- Err_obs(X);dimnames(O) <- list(J,J,J)
-  f <- colnames(X)
-  nn <- length(f)
-  cmbf <- combinations(n=nn, r=3, v=f, set=FALSE, repeats.allowed=FALSE)
+Err_obs_item <-function(X,K=K,n=n,J=J,O=O){
+  nn <- length(J)
+  cmbf <- combinations(n=nn, r=3, v=J, set=FALSE, repeats.allowed=FALSE)
   ncm <- nrow(cmbf)
   obs <- NULL
   for (i in 1 : nn){
     ind <- NULL;vind <- NULL
-    ind <- f[i]
+    ind <- J[i]
     for (g in 1:ncm){
       if (ind %in% cmbf[g,]){
         vind <- c(vind,g)
