@@ -1,7 +1,5 @@
-Err_obs_scale <-function(X){
-  vec <- colnames(X)
+Err_obs_scale <-function(X,vec=vec,o=o){
   l_vec <- length(vec)
-  o <-Err_obs(X);dimnames(o) <- list(vec, vec, vec)
   cmb1 <- combinations(n=l_vec, r=3, v=vec, set=FALSE, repeats.allowed=FALSE)
   return(sum(o[cmb1]))
-}
+}
\ No newline at end of file
